gedidb.L4CBeam
==============

.. currentmodule:: gedidb

.. autoclass:: L4CBeam

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L4CBeam.__init__
      ~L4CBeam.apply_filter
      ~L4CBeam.build_virtual_dataset
      ~L4CBeam.clear
      ~L4CBeam.copy
      ~L4CBeam.create_dataset
      ~L4CBeam.create_dataset_like
      ~L4CBeam.create_group
      ~L4CBeam.create_virtual_dataset
      ~L4CBeam.get
      ~L4CBeam.items
      ~L4CBeam.keys
      ~L4CBeam.move
      ~L4CBeam.pop
      ~L4CBeam.popitem
      ~L4CBeam.require_dataset
      ~L4CBeam.require_group
      ~L4CBeam.setdefault
      ~L4CBeam.update
      ~L4CBeam.values
      ~L4CBeam.visit
      ~L4CBeam.visit_links
      ~L4CBeam.visititems
      ~L4CBeam.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L4CBeam.attrs
      ~L4CBeam.beam_type
      ~L4CBeam.field_mapper
      ~L4CBeam.file
      ~L4CBeam.id
      ~L4CBeam.main_data
      ~L4CBeam.n_shots
      ~L4CBeam.name
      ~L4CBeam.parent
      ~L4CBeam.ref
      ~L4CBeam.regionref
   
   